@@ -75,8 +75,6 @@ import java.util.stream.Stream;
 import org.eclipse.che.api.core.ValidationException;
 import org.eclipse.che.api.core.model.workspace.runtime.RuntimeIdentity;
 import org.eclipse.che.api.user.server.PreferenceManager;
-import org.eclipse.che.api.user.server.UserManager;
-import org.eclipse.che.api.user.server.model.impl.UserImpl;
 import org.eclipse.che.api.workspace.server.model.impl.RuntimeIdentityImpl;
 import org.eclipse.che.api.workspace.server.model.impl.WorkspaceImpl;
 import org.eclipse.che.api.workspace.server.model.impl.WorkspaceImpl.WorkspaceImplBuilder;
@@ -87,10 +85,8 @@ import org.eclipse.che.commons.env.EnvironmentContext;
 import org.eclipse.che.commons.subject.SubjectImpl;
 import org.eclipse.che.inject.ConfigurationException;
 import org.eclipse.che.workspace.infrastructure.kubernetes.CheServerKubernetesClientFactory;
-import org.eclipse.che.workspace.infrastructure.kubernetes.KubernetesClientFactory;
 import org.eclipse.che.workspace.infrastructure.kubernetes.api.server.impls.KubernetesNamespaceMetaImpl;
 import org.eclipse.che.workspace.infrastructure.kubernetes.api.shared.KubernetesNamespaceMeta;
-import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.configurator.CredentialsSecretConfigurator;
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.configurator.NamespaceConfigurator;
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.configurator.PreferencesConfigMapConfigurator;
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.configurator.WorkspaceServiceAccountConfigurator;
@@ -126,10 +122,8 @@ public class KubernetesNamespaceFactoryTest {
   private static final String NAMESPACE_ANNOTATIONS = NAMESPACE_ANNOTATION_NAME + "=<username>";
 
   @Mock private KubernetesSharedPool pool;
-  @Mock private KubernetesClientFactory clientFactory;
-  @Mock private CheServerKubernetesClientFactory cheClientFactory;
+  @Mock private CheServerKubernetesClientFactory cheServerKubernetesClientFactory;
   private KubernetesClient k8sClient;
-  @Mock private UserManager userManager;
   @Mock private PreferenceManager preferenceManager;
   @Mock Appender mockedAppender;
 
@@ -150,8 +144,7 @@ public class KubernetesNamespaceFactoryTest {
     serverMock = new KubernetesServer(true, true);
     serverMock.before();
     k8sClient = spy(serverMock.getClient());
-    lenient().when(clientFactory.create()).thenReturn(k8sClient);
-    lenient().when(cheClientFactory.create()).thenReturn(k8sClient);
+    lenient().when(cheServerKubernetesClientFactory.create()).thenReturn(k8sClient);
     lenient().when(k8sClient.namespaces()).thenReturn(namespaceOperation);
 
     lenient().when(namespaceOperation.withName(any())).thenReturn(namespaceResource);
@@ -161,9 +154,6 @@ public class KubernetesNamespaceFactoryTest {
     lenient().when(namespaceListResource.list()).thenReturn(namespaceList);
     lenient().when(namespaceList.getItems()).thenReturn(Collections.emptyList());
 
-    lenient()
-        .when(userManager.getById(USER_ID))
-        .thenReturn(new UserImpl(USER_ID, "test@mail.com", USER_NAME));
     EnvironmentContext.getCurrent().setSubject(new SubjectImpl("jondoe", "i123", null, false));
   }
 
@@ -185,9 +175,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
 
@@ -212,9 +200,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
 
@@ -232,9 +218,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
 
@@ -257,9 +241,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
 
@@ -279,9 +261,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
   }
@@ -329,9 +309,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
     EnvironmentContext.getCurrent().setSubject(new SubjectImpl("jondoe", "123", null, false));
@@ -372,9 +350,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
     EnvironmentContext.getCurrent().setSubject(new SubjectImpl("jondoe", "123", null, false));
@@ -402,9 +378,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
 
@@ -435,9 +409,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
 
@@ -463,9 +435,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
 
@@ -480,45 +450,6 @@ public class KubernetesNamespaceFactoryTest {
             .get(PHASE_ATTRIBUTE)); // no phase - means such namespace does not exist
   }
 
-  @Test
-  public void shouldCreateCredentialsSecretIfNotExists() throws Exception {
-    // given
-    namespaceFactory =
-        spy(
-            new KubernetesNamespaceFactory(
-                "<username>-che",
-                true,
-                true,
-                true,
-                NAMESPACE_LABELS,
-                NAMESPACE_ANNOTATIONS,
-                Set.of(new CredentialsSecretConfigurator(clientFactory)),
-                clientFactory,
-                cheClientFactory,
-                userManager,
-                preferenceManager,
-                pool));
-    KubernetesNamespace toReturnNamespace = mock(KubernetesNamespace.class);
-    when(toReturnNamespace.getName()).thenReturn("namespaceName");
-    doReturn(toReturnNamespace).when(namespaceFactory).doCreateNamespaceAccess(any(), any());
-    MixedOperation mixedOperation = mock(MixedOperation.class);
-    when(k8sClient.secrets()).thenReturn(mixedOperation);
-    when(mixedOperation.inNamespace(anyString())).thenReturn(namespaceOperation);
-    when(namespaceResource.get()).thenReturn(null);
-
-    // when
-    RuntimeIdentity identity =
-        new RuntimeIdentityImpl("workspace123", null, USER_ID, "workspace123");
-    namespaceFactory.getOrCreate(identity);
-
-    // then
-    ArgumentCaptor<Secret> secretsCaptor = ArgumentCaptor.forClass(Secret.class);
-    verify(namespaceOperation).create(secretsCaptor.capture());
-    Secret secret = secretsCaptor.getValue();
-    Assert.assertEquals(secret.getMetadata().getName(), CREDENTIALS_SECRET_NAME);
-    Assert.assertEquals(secret.getType(), "opaque");
-  }
-
   @Test
   public void shouldCreatePreferencesConfigmapIfNotExists() throws Exception {
     // given
@@ -531,10 +462,8 @@ public class KubernetesNamespaceFactoryTest {
                 true,
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
-                Set.of(new PreferencesConfigMapConfigurator(clientFactory)),
-                clientFactory,
-                cheClientFactory,
-                userManager,
+                Set.of(new PreferencesConfigMapConfigurator(cheServerKubernetesClientFactory)),
+                cheServerKubernetesClientFactory,
                 preferenceManager,
                 pool));
     KubernetesNamespace toReturnNamespace = mock(KubernetesNamespace.class);
@@ -575,9 +504,7 @@ public class KubernetesNamespaceFactoryTest {
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
                 namespaceConfigurators,
-                clientFactory,
-                cheClientFactory,
-                userManager,
+                cheServerKubernetesClientFactory,
                 preferenceManager,
                 pool));
     EnvironmentContext.getCurrent().setSubject(new SubjectImpl("jondoe", "123", null, false));
@@ -612,9 +539,7 @@ public class KubernetesNamespaceFactoryTest {
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
                 emptySet(),
-                clientFactory,
-                cheClientFactory,
-                userManager,
+                cheServerKubernetesClientFactory,
                 preferenceManager,
                 pool));
     KubernetesNamespace toReturnNamespace = mock(KubernetesNamespace.class);
@@ -646,9 +571,7 @@ public class KubernetesNamespaceFactoryTest {
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
                 emptySet(),
-                clientFactory,
-                cheClientFactory,
-                userManager,
+                cheServerKubernetesClientFactory,
                 preferenceManager,
                 pool));
     KubernetesNamespace toReturnNamespace = mock(KubernetesNamespace.class);
@@ -681,9 +604,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
     throwOnTryToGetNamespaceByName(
@@ -706,9 +627,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
     throwOnTryToGetNamespacesList(new KubernetesClientException("connection refused"));
@@ -736,9 +655,7 @@ public class KubernetesNamespaceFactoryTest {
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
                 emptySet(),
-                clientFactory,
-                cheClientFactory,
-                userManager,
+                cheServerKubernetesClientFactory,
                 preferenceManager,
                 pool));
     KubernetesNamespace toReturnNamespace = mock(KubernetesNamespace.class);
@@ -767,9 +684,7 @@ public class KubernetesNamespaceFactoryTest {
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
                 emptySet(),
-                clientFactory,
-                cheClientFactory,
-                userManager,
+                cheServerKubernetesClientFactory,
                 preferenceManager,
                 pool));
     KubernetesNamespace toReturnNamespace = mock(KubernetesNamespace.class);
@@ -791,7 +706,9 @@ public class KubernetesNamespaceFactoryTest {
       throws Exception {
     // given
     var serviceAccountCfg =
-        spy(new WorkspaceServiceAccountConfigurator("serviceAccount", "", clientFactory));
+        spy(
+            new WorkspaceServiceAccountConfigurator(
+                "serviceAccount", "", cheServerKubernetesClientFactory));
     namespaceFactory =
         spy(
             new KubernetesNamespaceFactory(
@@ -802,9 +719,7 @@ public class KubernetesNamespaceFactoryTest {
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
                 Set.of(serviceAccountCfg),
-                clientFactory,
-                cheClientFactory,
-                userManager,
+                cheServerKubernetesClientFactory,
                 preferenceManager,
                 pool));
     KubernetesNamespace toReturnNamespace = mock(KubernetesNamespace.class);
@@ -830,7 +745,8 @@ public class KubernetesNamespaceFactoryTest {
   public void shouldBindToAllConfiguredClusterRoles() throws Exception {
     // given
     var serviceAccountConfigurator =
-        new WorkspaceServiceAccountConfigurator("serviceAccount", "cr2, cr3", clientFactory);
+        new WorkspaceServiceAccountConfigurator(
+            "serviceAccount", "cr2, cr3", cheServerKubernetesClientFactory);
     namespaceFactory =
         spy(
             new KubernetesNamespaceFactory(
@@ -841,9 +757,7 @@ public class KubernetesNamespaceFactoryTest {
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
                 Set.of(serviceAccountConfigurator),
-                clientFactory,
-                cheClientFactory,
-                userManager,
+                cheServerKubernetesClientFactory,
                 preferenceManager,
                 pool));
     KubernetesNamespace toReturnNamespace = mock(KubernetesNamespace.class);
@@ -851,7 +765,7 @@ public class KubernetesNamespaceFactoryTest {
     when(toReturnNamespace.getName()).thenReturn("workspace123");
     doReturn(toReturnNamespace).when(namespaceFactory).doCreateNamespaceAccess(any(), any());
     when(k8sClient.supportsApiPath(eq("/apis/metrics.k8s.io"))).thenReturn(true);
-    when(clientFactory.create(any())).thenReturn(k8sClient);
+    when(cheServerKubernetesClientFactory.create(any())).thenReturn(k8sClient);
 
     // pre-create the cluster roles
     Stream.of("cr1", "cr2", "cr3")
@@ -906,7 +820,8 @@ public class KubernetesNamespaceFactoryTest {
   public void shouldCreateAndBindCredentialsSecretRole() throws Exception {
     // given
     var serviceAccountConfigurator =
-        new WorkspaceServiceAccountConfigurator("serviceAccount", "cr2, cr3", clientFactory);
+        new WorkspaceServiceAccountConfigurator(
+            "serviceAccount", "cr2, cr3", cheServerKubernetesClientFactory);
     namespaceFactory =
         spy(
             new KubernetesNamespaceFactory(
@@ -917,16 +832,14 @@ public class KubernetesNamespaceFactoryTest {
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
                 Set.of(serviceAccountConfigurator),
-                clientFactory,
-                cheClientFactory,
-                userManager,
+                cheServerKubernetesClientFactory,
                 preferenceManager,
                 pool));
     KubernetesNamespace toReturnNamespace = mock(KubernetesNamespace.class);
     prepareNamespace(toReturnNamespace);
     when(toReturnNamespace.getName()).thenReturn("workspace123");
     doReturn(toReturnNamespace).when(namespaceFactory).doCreateNamespaceAccess(any(), any());
-    when(clientFactory.create(any())).thenReturn(k8sClient);
+    when(cheServerKubernetesClientFactory.create(any())).thenReturn(k8sClient);
 
     // when
     RuntimeIdentity identity =
@@ -962,10 +875,9 @@ public class KubernetesNamespaceFactoryTest {
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
                 Set.of(
-                    new WorkspaceServiceAccountConfigurator("serviceAccount", "", clientFactory)),
-                clientFactory,
-                cheClientFactory,
-                userManager,
+                    new WorkspaceServiceAccountConfigurator(
+                        "serviceAccount", "", cheServerKubernetesClientFactory)),
+                cheServerKubernetesClientFactory,
                 preferenceManager,
                 pool));
     KubernetesNamespace toReturnNamespace = mock(KubernetesNamespace.class);
@@ -973,7 +885,7 @@ public class KubernetesNamespaceFactoryTest {
     when(toReturnNamespace.getName()).thenReturn("workspace123");
     doReturn(toReturnNamespace).when(namespaceFactory).doCreateNamespaceAccess(any(), any());
     when(k8sClient.supportsApiPath(eq("/apis/metrics.k8s.io"))).thenReturn(true);
-    when(clientFactory.create(any())).thenReturn(k8sClient);
+    when(cheServerKubernetesClientFactory.create(any())).thenReturn(k8sClient);
 
     // when
     RuntimeIdentity identity =
@@ -1029,9 +941,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
 
@@ -1054,9 +964,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
 
@@ -1084,9 +992,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
 
@@ -1115,9 +1021,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
 
@@ -1146,9 +1050,7 @@ public class KubernetesNamespaceFactoryTest {
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
                 emptySet(),
-                clientFactory,
-                cheClientFactory,
-                userManager,
+                cheServerKubernetesClientFactory,
                 preferenceManager,
                 pool));
     doReturn(empty()).when(namespaceFactory).fetchNamespace(anyString());
@@ -1173,9 +1075,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
 
@@ -1202,9 +1102,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
 
@@ -1252,9 +1150,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
 
@@ -1278,9 +1174,7 @@ public class KubernetesNamespaceFactoryTest {
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
                 emptySet(),
-                clientFactory,
-                cheClientFactory,
-                userManager,
+                cheServerKubernetesClientFactory,
                 preferenceManager,
                 pool));
     KubernetesNamespace toReturnNamespace = mock(KubernetesNamespace.class);
@@ -1317,9 +1211,7 @@ public class KubernetesNamespaceFactoryTest {
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
                 emptySet(),
-                clientFactory,
-                cheClientFactory,
-                userManager,
+                cheServerKubernetesClientFactory,
                 preferenceManager,
                 pool));
     KubernetesNamespace toReturnNamespace = mock(KubernetesNamespace.class);
@@ -1355,9 +1247,7 @@ public class KubernetesNamespaceFactoryTest {
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
                 emptySet(),
-                clientFactory,
-                cheClientFactory,
-                userManager,
+                cheServerKubernetesClientFactory,
                 preferenceManager,
                 pool));
     KubernetesNamespace toReturnNamespace = mock(KubernetesNamespace.class);
@@ -1405,9 +1295,7 @@ public class KubernetesNamespaceFactoryTest {
             "try_placeholder_here=<username>",
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
     EnvironmentContext.getCurrent().setSubject(new SubjectImpl("jondoe", "123", null, false));
@@ -1430,9 +1318,7 @@ public class KubernetesNamespaceFactoryTest {
                 NAMESPACE_LABELS,
                 "try_placeholder_here=<username>",
                 emptySet(),
-                clientFactory,
-                cheClientFactory,
-                userManager,
+                cheServerKubernetesClientFactory,
                 preferenceManager,
                 pool));
     EnvironmentContext.getCurrent().setSubject(new SubjectImpl("jondoe", "123", null, false));
@@ -1461,9 +1347,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
     assertEquals(expected, namespaceFactory.normalizeNamespaceName(raw));
@@ -1480,9 +1364,7 @@ public class KubernetesNamespaceFactoryTest {
             NAMESPACE_LABELS,
             NAMESPACE_ANNOTATIONS,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
-            userManager,
+            cheServerKubernetesClientFactory,
             preferenceManager,
             pool);
 
