@@ -61,8 +61,6 @@ import java.util.Set;
 import org.eclipse.che.api.core.ValidationException;
 import org.eclipse.che.api.core.model.workspace.runtime.RuntimeIdentity;
 import org.eclipse.che.api.user.server.PreferenceManager;
-import org.eclipse.che.api.user.server.UserManager;
-import org.eclipse.che.api.user.server.model.impl.UserImpl;
 import org.eclipse.che.api.workspace.server.WorkspaceManager;
 import org.eclipse.che.api.workspace.server.model.impl.RuntimeIdentityImpl;
 import org.eclipse.che.api.workspace.server.model.impl.WorkspaceImpl;
@@ -75,7 +73,6 @@ import org.eclipse.che.workspace.infrastructure.kubernetes.CheServerKubernetesCl
 import org.eclipse.che.workspace.infrastructure.kubernetes.api.shared.KubernetesNamespaceMeta;
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.KubernetesConfigsMaps;
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.KubernetesSecrets;
-import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.configurator.CredentialsSecretConfigurator;
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.configurator.NamespaceConfigurator;
 import org.eclipse.che.workspace.infrastructure.kubernetes.namespace.configurator.PreferencesConfigMapConfigurator;
 import org.eclipse.che.workspace.infrastructure.kubernetes.util.KubernetesSharedPool;
@@ -110,11 +107,10 @@ public class OpenShiftProjectFactoryTest {
   private static final String NAMESPACE_ANNOTATIONS = NAMESPACE_ANNOTATION_NAME + "=<username>";
 
   //  @Mock private OpenShiftClientConfigFactory configFactory;
-  @Mock private OpenShiftClientFactory clientFactory;
-  @Mock private CheServerKubernetesClientFactory cheClientFactory;
+  @Mock private OpenShiftClientFactory openShiftClientFactory;
+  @Mock private CheServerKubernetesClientFactory cheServerKubernetesClientFactory;
   @Mock private CheServerOpenshiftClientFactory cheServerOpenshiftClientFactory;
   @Mock private WorkspaceManager workspaceManager;
-  @Mock private UserManager userManager;
   @Mock private PreferenceManager preferenceManager;
   @Mock private KubernetesSharedPool pool;
 
@@ -132,8 +128,10 @@ public class OpenShiftProjectFactoryTest {
 
   @BeforeMethod
   public void setUp() throws Exception {
-    lenient().when(clientFactory.createOC()).thenReturn(osClient);
-    lenient().when(clientFactory.create()).thenReturn(osClient);
+    lenient().when(openShiftClientFactory.createOC()).thenReturn(osClient);
+    lenient().when(cheServerOpenshiftClientFactory.create()).thenReturn(osClient);
+    lenient().when(cheServerOpenshiftClientFactory.createOC()).thenReturn(osClient);
+    lenient().when(cheServerKubernetesClientFactory.create()).thenReturn(osClient);
     lenient().when(osClient.projects()).thenReturn(projectOperation);
 
     lenient()
@@ -147,9 +145,6 @@ public class OpenShiftProjectFactoryTest {
     lenient().when(projectListResource.list()).thenReturn(projectList);
     lenient().when(projectList.getItems()).thenReturn(emptyList());
 
-    lenient()
-        .when(userManager.getById(USER_ID))
-        .thenReturn(new UserImpl(USER_ID, "test@mail.com", USER_NAME));
     EnvironmentContext.getCurrent()
         .setSubject(new SubjectImpl(USER_NAME, USER_ID, "t-354t53xff34234", false));
   }
@@ -173,10 +168,9 @@ public class OpenShiftProjectFactoryTest {
             NAMESPACE_ANNOTATIONS,
             true,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
+            openShiftClientFactory,
+            cheServerKubernetesClientFactory,
             cheServerOpenshiftClientFactory,
-            userManager,
             preferenceManager,
             pool,
             NO_OAUTH_IDENTITY_PROVIDER);
@@ -204,10 +198,9 @@ public class OpenShiftProjectFactoryTest {
             NAMESPACE_ANNOTATIONS,
             true,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
+            openShiftClientFactory,
+            cheServerKubernetesClientFactory,
             cheServerOpenshiftClientFactory,
-            userManager,
             preferenceManager,
             pool,
             NO_OAUTH_IDENTITY_PROVIDER);
@@ -235,10 +228,9 @@ public class OpenShiftProjectFactoryTest {
             NAMESPACE_ANNOTATIONS,
             true,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
+            openShiftClientFactory,
+            cheServerKubernetesClientFactory,
             cheServerOpenshiftClientFactory,
-            userManager,
             preferenceManager,
             pool,
             NO_OAUTH_IDENTITY_PROVIDER);
@@ -271,10 +263,9 @@ public class OpenShiftProjectFactoryTest {
             NAMESPACE_ANNOTATIONS,
             true,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
+            openShiftClientFactory,
+            cheServerKubernetesClientFactory,
             cheServerOpenshiftClientFactory,
-            userManager,
             preferenceManager,
             pool,
             NO_OAUTH_IDENTITY_PROVIDER);
@@ -308,10 +299,9 @@ public class OpenShiftProjectFactoryTest {
             NAMESPACE_ANNOTATIONS,
             true,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
+            openShiftClientFactory,
+            cheServerKubernetesClientFactory,
             cheServerOpenshiftClientFactory,
-            userManager,
             preferenceManager,
             pool,
             NO_OAUTH_IDENTITY_PROVIDER);
@@ -341,10 +331,9 @@ public class OpenShiftProjectFactoryTest {
             NAMESPACE_ANNOTATIONS,
             true,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
+            openShiftClientFactory,
+            cheServerKubernetesClientFactory,
             cheServerOpenshiftClientFactory,
-            userManager,
             preferenceManager,
             pool,
             NO_OAUTH_IDENTITY_PROVIDER);
@@ -384,10 +373,9 @@ public class OpenShiftProjectFactoryTest {
             NAMESPACE_ANNOTATIONS,
             true,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
+            openShiftClientFactory,
+            cheServerKubernetesClientFactory,
             cheServerOpenshiftClientFactory,
-            userManager,
             preferenceManager,
             pool,
             NO_OAUTH_IDENTITY_PROVIDER);
@@ -421,10 +409,9 @@ public class OpenShiftProjectFactoryTest {
             NAMESPACE_ANNOTATIONS,
             true,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
+            openShiftClientFactory,
+            cheServerKubernetesClientFactory,
             cheServerOpenshiftClientFactory,
-            userManager,
             preferenceManager,
             pool,
             NO_OAUTH_IDENTITY_PROVIDER);
@@ -458,10 +445,9 @@ public class OpenShiftProjectFactoryTest {
             NAMESPACE_ANNOTATIONS,
             true,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
+            openShiftClientFactory,
+            cheServerKubernetesClientFactory,
             cheServerOpenshiftClientFactory,
-            userManager,
             preferenceManager,
             pool,
             NO_OAUTH_IDENTITY_PROVIDER);
@@ -485,10 +471,9 @@ public class OpenShiftProjectFactoryTest {
             NAMESPACE_ANNOTATIONS,
             true,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
+            openShiftClientFactory,
+            cheServerKubernetesClientFactory,
             cheServerOpenshiftClientFactory,
-            userManager,
             preferenceManager,
             pool,
             NO_OAUTH_IDENTITY_PROVIDER);
@@ -517,10 +502,9 @@ public class OpenShiftProjectFactoryTest {
                 NAMESPACE_ANNOTATIONS,
                 true,
                 emptySet(),
-                clientFactory,
-                cheClientFactory,
+                openShiftClientFactory,
+                cheServerKubernetesClientFactory,
                 cheServerOpenshiftClientFactory,
-                userManager,
                 preferenceManager,
                 pool,
                 NO_OAUTH_IDENTITY_PROVIDER));
@@ -538,51 +522,6 @@ public class OpenShiftProjectFactoryTest {
     verify(toReturnProject).prepare(eq(true), eq(false), any(), any());
   }
 
-  @Test
-  public void shouldCreateCredentialsSecretIfNotExists() throws Exception {
-    // given
-    projectFactory =
-        spy(
-            new OpenShiftProjectFactory(
-                "<userid>-che",
-                true,
-                true,
-                true,
-                NAMESPACE_LABELS,
-                NAMESPACE_ANNOTATIONS,
-                true,
-                Set.of(new CredentialsSecretConfigurator(clientFactory)),
-                clientFactory,
-                cheClientFactory,
-                cheServerOpenshiftClientFactory,
-                userManager,
-                preferenceManager,
-                pool,
-                NO_OAUTH_IDENTITY_PROVIDER));
-    OpenShiftProject toReturnProject = mock(OpenShiftProject.class);
-    doReturn(toReturnProject).when(projectFactory).doCreateProjectAccess(any(), any());
-    when(toReturnProject.getName()).thenReturn("namespace123");
-    NonNamespaceOperation namespaceOperation = mock(NonNamespaceOperation.class);
-    MixedOperation mixedOperation = mock(MixedOperation.class);
-    when(osClient.secrets()).thenReturn(mixedOperation);
-    when(mixedOperation.inNamespace(anyString())).thenReturn(namespaceOperation);
-    Resource<Secret> nullSecret = mock(Resource.class);
-    when(namespaceOperation.withName(CREDENTIALS_SECRET_NAME)).thenReturn(nullSecret);
-    when(nullSecret.get()).thenReturn(null);
-
-    // when
-    RuntimeIdentity identity =
-        new RuntimeIdentityImpl("workspace123", null, USER_ID, "namespace123");
-    projectFactory.getOrCreate(identity);
-
-    // then
-    ArgumentCaptor<Secret> secretsCaptor = ArgumentCaptor.forClass(Secret.class);
-    verify(namespaceOperation).create(secretsCaptor.capture());
-    Secret secret = secretsCaptor.getValue();
-    Assert.assertEquals(secret.getMetadata().getName(), CREDENTIALS_SECRET_NAME);
-    Assert.assertEquals(secret.getType(), "opaque");
-  }
-
   @Test
   public void shouldCreatePreferencesConfigmapIfNotExists() throws Exception {
     // given
@@ -596,11 +535,10 @@ public class OpenShiftProjectFactoryTest {
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
                 true,
-                Set.of(new PreferencesConfigMapConfigurator(clientFactory)),
-                clientFactory,
-                cheClientFactory,
+                Set.of(new PreferencesConfigMapConfigurator(cheServerKubernetesClientFactory)),
+                openShiftClientFactory,
+                cheServerKubernetesClientFactory,
                 cheServerOpenshiftClientFactory,
-                userManager,
                 preferenceManager,
                 pool,
                 NO_OAUTH_IDENTITY_PROVIDER));
@@ -626,48 +564,6 @@ public class OpenShiftProjectFactoryTest {
     Assert.assertEquals(configmap.getMetadata().getName(), PREFERENCES_CONFIGMAP_NAME);
   }
 
-  @Test
-  public void shouldNotCreateCredentialsSecretIfExist() throws Exception {
-    // given
-    projectFactory =
-        spy(
-            new OpenShiftProjectFactory(
-                "<userid>-che",
-                true,
-                true,
-                true,
-                NAMESPACE_LABELS,
-                NAMESPACE_ANNOTATIONS,
-                true,
-                Set.of(new CredentialsSecretConfigurator(clientFactory)),
-                clientFactory,
-                cheClientFactory,
-                cheServerOpenshiftClientFactory,
-                userManager,
-                preferenceManager,
-                pool,
-                NO_OAUTH_IDENTITY_PROVIDER));
-    OpenShiftProject toReturnProject = mock(OpenShiftProject.class);
-    prepareProject(toReturnProject);
-    doReturn(toReturnProject).when(projectFactory).doCreateProjectAccess(any(), any());
-    when(toReturnProject.getName()).thenReturn("namespace123");
-    NonNamespaceOperation namespaceOperation = mock(NonNamespaceOperation.class);
-    MixedOperation mixedOperation = mock(MixedOperation.class);
-    when(osClient.secrets()).thenReturn(mixedOperation);
-    when(mixedOperation.inNamespace(anyString())).thenReturn(namespaceOperation);
-    Resource<Secret> secretResource = mock(Resource.class);
-    when(namespaceOperation.withName(CREDENTIALS_SECRET_NAME)).thenReturn(secretResource);
-    when(secretResource.get()).thenReturn(mock(Secret.class));
-
-    // when
-    RuntimeIdentity identity =
-        new RuntimeIdentityImpl("workspace123", null, USER_ID, "workspace123");
-    projectFactory.getOrCreate(identity);
-
-    // then
-    verify(namespaceOperation, never()).create(any());
-  }
-
   @Test
   public void shouldNotCreatePreferencesConfigmapIfExist() throws Exception {
     // given
@@ -681,11 +577,10 @@ public class OpenShiftProjectFactoryTest {
                 NAMESPACE_LABELS,
                 NAMESPACE_ANNOTATIONS,
                 true,
-                Set.of(new PreferencesConfigMapConfigurator(clientFactory)),
-                clientFactory,
-                cheClientFactory,
+                Set.of(new PreferencesConfigMapConfigurator(cheServerKubernetesClientFactory)),
+                openShiftClientFactory,
+                cheServerKubernetesClientFactory,
                 cheServerOpenshiftClientFactory,
-                userManager,
                 preferenceManager,
                 pool,
                 NO_OAUTH_IDENTITY_PROVIDER));
@@ -713,7 +608,9 @@ public class OpenShiftProjectFactoryTest {
   @Test
   public void shouldCallStopWorkspaceRoleProvisionWhenIdentityProviderIsDefined() throws Exception {
     var saConf =
-        spy(new OpenShiftWorkspaceServiceAccountConfigurator("serviceAccount", "", clientFactory));
+        spy(
+            new OpenShiftWorkspaceServiceAccountConfigurator(
+                "serviceAccount", "", cheServerOpenshiftClientFactory));
     projectFactory =
         spy(
             new OpenShiftProjectFactory(
@@ -725,10 +622,9 @@ public class OpenShiftProjectFactoryTest {
                 NAMESPACE_ANNOTATIONS,
                 true,
                 Set.of(saConf),
-                clientFactory,
-                cheClientFactory,
+                openShiftClientFactory,
+                cheServerKubernetesClientFactory,
                 cheServerOpenshiftClientFactory,
-                userManager,
                 preferenceManager,
                 pool,
                 OAUTH_IDENTITY_PROVIDER));
@@ -775,10 +671,9 @@ public class OpenShiftProjectFactoryTest {
             NAMESPACE_ANNOTATIONS,
             true,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
+            openShiftClientFactory,
+            cheServerKubernetesClientFactory,
             cheServerOpenshiftClientFactory,
-            userManager,
             preferenceManager,
             pool,
             NO_OAUTH_IDENTITY_PROVIDER);
@@ -808,10 +703,9 @@ public class OpenShiftProjectFactoryTest {
             NAMESPACE_ANNOTATIONS,
             true,
             emptySet(),
-            clientFactory,
-            cheClientFactory,
+            openShiftClientFactory,
+            cheServerKubernetesClientFactory,
             cheServerOpenshiftClientFactory,
-            userManager,
             preferenceManager,
             pool,
             NO_OAUTH_IDENTITY_PROVIDER);
@@ -835,10 +729,9 @@ public class OpenShiftProjectFactoryTest {
                 "try_placeholder_here=<username>",
                 true,
                 emptySet(),
-                clientFactory,
-                cheClientFactory,
+                openShiftClientFactory,
+                cheServerKubernetesClientFactory,
                 cheServerOpenshiftClientFactory,
-                userManager,
                 preferenceManager,
                 pool,
                 NO_OAUTH_IDENTITY_PROVIDER));
@@ -876,10 +769,9 @@ public class OpenShiftProjectFactoryTest {
                 "try_placeholder_here=<username>",
                 true,
                 namespaceConfigurators,
-                clientFactory,
-                cheClientFactory,
+                openShiftClientFactory,
+                cheServerKubernetesClientFactory,
                 cheServerOpenshiftClientFactory,
-                userManager,
                 preferenceManager,
                 pool,
                 NO_OAUTH_IDENTITY_PROVIDER));
