@@ -22,7 +22,7 @@ import javax.inject.Inject;
 import javax.inject.Singleton;
 import org.eclipse.che.api.core.ApiException;
 import org.eclipse.che.api.core.BadRequestException;
-import org.eclipse.che.api.factory.server.DefaultFactoryParameterResolver;
+import org.eclipse.che.api.factory.server.RawDevfileUrlFactoryParameterResolver;
 import org.eclipse.che.api.factory.server.scm.PersonalAccessTokenManager;
 import org.eclipse.che.api.factory.server.urlfactory.ProjectConfigDtoMerger;
 import org.eclipse.che.api.factory.server.urlfactory.RemoteFactoryUrl;
@@ -38,7 +38,7 @@ import org.eclipse.che.api.workspace.shared.dto.devfile.ProjectDto;
 
 /** Provides Factory Parameters resolver for bitbucket repositories. */
 @Singleton
-public class BitbucketFactoryParametersResolver extends DefaultFactoryParameterResolver {
+public class BitbucketFactoryParametersResolver extends RawDevfileUrlFactoryParameterResolver {
 
   /** Parser which will allow to check validity of URLs and create objects. */
   private final BitbucketURLParser bitbucketURLParser;
