@@ -46,7 +46,7 @@ public class GitlabUrlParser {
   private final PersonalAccessTokenManager personalAccessTokenManager;
   private static final List<String> gitlabUrlPatternTemplates =
       List.of(
-          "^(?<host>%s)/(?<subgroups>([^/]++/?)+)/-/tree/(?<branch>[^/]++)(/)?(?<subfolder>[^/]++)?",
+          "^(?<host>%s)/(?<subgroups>([^/]++/?)+)/-/tree/(?<branch>.++)(/)?",
           "^(?<host>%s)/(?<subgroups>.*)"); // a wider one, should be the last in the
   // list
   private final List<Pattern> gitlabUrlPatterns = new ArrayList<>();
@@ -93,7 +93,8 @@ public class GitlabUrlParser {
   }
 
   public boolean isValid(@NotNull String url) {
-    return gitlabUrlPatterns.stream().anyMatch(pattern -> pattern.matcher(url).matches())
+    return gitlabUrlPatterns.stream()
+            .anyMatch(pattern -> pattern.matcher(trimEnd(url, '/')).matches())
         // If the Gitlab URL is not configured, try to find it in a manually added user namespace
         // token.
         || isUserTokenPresent(url)
@@ -108,7 +109,7 @@ public class GitlabUrlParser {
       try {
         // If the token request catches the unauthorised error, it means that the provided url
         // belongs to Gitlab.
-        gitlabApiClient.getTokenInfo("");
+        gitlabApiClient.getOAuthTokenInfo("");
       } catch (ScmCommunicationException e) {
         return e.getStatusCode() == HTTP_UNAUTHORIZED;
       } catch (ScmItemNotFoundException e) {
@@ -144,15 +145,15 @@ public class GitlabUrlParser {
    * {@link GitlabUrl} objects.
    */
   public GitlabUrl parse(String url) {
-
+    String trimmedUrl = trimEnd(url, '/');
     Optional<Matcher> matcherOptional =
         gitlabUrlPatterns.stream()
-            .map(pattern -> pattern.matcher(url))
+            .map(pattern -> pattern.matcher(trimmedUrl))
             .filter(Matcher::matches)
             .findFirst()
-            .or(() -> getPatternMatcherByUrl(url));
+            .or(() -> getPatternMatcherByUrl(trimmedUrl));
     if (matcherOptional.isPresent()) {
-      return parse(matcherOptional.get()).withUrl(url);
+      return parse(matcherOptional.get()).withUrl(trimmedUrl);
     } else {
       throw new UnsupportedOperationException(
           "The gitlab integration is not configured properly and cannot be used at this moment."
@@ -168,23 +169,16 @@ public class GitlabUrlParser {
     }
 
     String branch = null;
-    String subfolder = null;
     try {
       branch = matcher.group("branch");
     } catch (IllegalArgumentException e) {
       // ok no such group
     }
-    try {
-      subfolder = matcher.group("subfolder");
-    } catch (IllegalArgumentException e) {
-      // ok no such group
-    }
 
     return new GitlabUrl()
         .withHostName(host)
         .withSubGroups(subGroups)
         .withBranch(branch)
-        .withSubfolder(subfolder)
         .withDevfileFilenames(devfileFilenamesProvider.getConfiguredDevfileFilenames());
   }
 }
