@@ -11,7 +11,6 @@
  */
 package org.eclipse.che.api.factory.server.gitlab;
 
-import static java.lang.String.format;
 import static java.util.stream.Collectors.toList;
 
 import com.google.common.base.Joiner;
@@ -23,29 +22,17 @@ import java.util.Set;
 import javax.inject.Inject;
 import javax.inject.Named;
 import org.eclipse.che.api.auth.shared.dto.OAuthToken;
-import org.eclipse.che.api.core.BadRequestException;
-import org.eclipse.che.api.core.ConflictException;
-import org.eclipse.che.api.core.ForbiddenException;
-import org.eclipse.che.api.core.NotFoundException;
-import org.eclipse.che.api.core.ServerException;
-import org.eclipse.che.api.core.UnauthorizedException;
-import org.eclipse.che.api.factory.server.scm.GitUserData;
-import org.eclipse.che.api.factory.server.scm.GitUserDataFetcher;
+import org.eclipse.che.api.factory.server.scm.*;
 import org.eclipse.che.api.factory.server.scm.exception.ScmBadRequestException;
 import org.eclipse.che.api.factory.server.scm.exception.ScmCommunicationException;
 import org.eclipse.che.api.factory.server.scm.exception.ScmItemNotFoundException;
-import org.eclipse.che.api.factory.server.scm.exception.ScmUnauthorizedException;
 import org.eclipse.che.commons.annotation.Nullable;
-import org.eclipse.che.commons.env.EnvironmentContext;
 import org.eclipse.che.commons.lang.StringUtils;
-import org.eclipse.che.commons.subject.Subject;
 import org.eclipse.che.inject.ConfigurationException;
-import org.eclipse.che.security.oauth.OAuthAPI;
 
 /** Gitlab OAuth token retriever. */
-public class GitlabUserDataFetcher implements GitUserDataFetcher {
+public class GitlabUserDataFetcher extends AbstractGitUserDataFetcher {
   private final String apiEndpoint;
-  private final OAuthAPI oAuthAPI;
 
   /** Name of this OAuth provider as found in OAuthAPI. */
   private static final String OAUTH_PROVIDER_NAME = "gitlab";
@@ -60,7 +47,9 @@ public class GitlabUserDataFetcher implements GitUserDataFetcher {
       @Nullable @Named("che.integration.gitlab.server_endpoints") String gitlabEndpoints,
       @Nullable @Named("che.integration.gitlab.oauth_endpoint") String oauthEndpoint,
       @Named("che.api") String apiEndpoint,
-      OAuthAPI oAuthAPI) {
+      PersonalAccessTokenManager personalAccessTokenManager,
+      OAuthTokenFetcher oAuthTokenFetcher) {
+    super(OAUTH_PROVIDER_NAME, personalAccessTokenManager, oAuthTokenFetcher);
     this.apiEndpoint = apiEndpoint;
     if (gitlabEndpoints != null) {
       this.registeredGitlabEndpoints =
@@ -76,58 +65,30 @@ public class GitlabUserDataFetcher implements GitUserDataFetcher {
         throw new ConfigurationException(
             "GitLab OAuth integration endpoint must be present in registered GitLab endpoints list.");
       }
-      this.oAuthAPI = oAuthAPI;
-    } else {
-      this.oAuthAPI = null;
     }
   }
 
   @Override
-  public GitUserData fetchGitUserData() throws ScmUnauthorizedException, ScmCommunicationException {
-    if (oAuthAPI == null) {
-      throw new ScmCommunicationException(
-          format(
-              "OAuth 2 is not configured for SCM provider [%s]. For details, refer "
-                  + "the documentation in section of SCM providers configuration.",
-              OAUTH_PROVIDER_NAME));
-    }
-    OAuthToken oAuthToken;
-    try {
-      oAuthToken = oAuthAPI.getToken(OAUTH_PROVIDER_NAME);
-    } catch (UnauthorizedException e) {
-      Subject cheSubject = EnvironmentContext.getCurrent().getSubject();
-      throw new ScmUnauthorizedException(
-          cheSubject.getUserName()
-              + " is not authorized in "
-              + OAUTH_PROVIDER_NAME
-              + " OAuth provider.",
-          OAUTH_PROVIDER_NAME,
-          "2.0",
-          getLocalAuthenticateUrl());
-    } catch (NotFoundException
-        | ServerException
-        | ForbiddenException
-        | BadRequestException
-        | ConflictException e) {
-      throw new ScmCommunicationException(e.getMessage(), e);
-    }
-    GitUserData gitUserData = null;
+  protected GitUserData fetchGitUserDataWithOAuthToken(OAuthToken oAuthToken)
+      throws ScmItemNotFoundException, ScmCommunicationException, ScmBadRequestException {
     for (String gitlabServerEndpoint : this.registeredGitlabEndpoints) {
-      try {
-        GitlabUser user = new GitlabApiClient(gitlabServerEndpoint).getUser(oAuthToken.getToken());
-        gitUserData = new GitUserData(user.getName(), user.getEmail());
-        break;
-      } catch (ScmItemNotFoundException | ScmBadRequestException e) {
-        throw new ScmCommunicationException(e.getMessage(), e);
-      }
+      GitlabUser user = new GitlabApiClient(gitlabServerEndpoint).getUser(oAuthToken.getToken());
+      return new GitUserData(user.getName(), user.getEmail());
     }
-    if (gitUserData == null) {
-      throw new ScmCommunicationException("Failed to retrieve git user data from Gitlab");
-    }
-    return gitUserData;
+    throw new ScmCommunicationException("Failed to retrieve git user data from Gitlab");
   }
 
-  private String getLocalAuthenticateUrl() {
+  @Override
+  protected GitUserData fetchGitUserDataWithPersonalAccessToken(
+      PersonalAccessToken personalAccessToken)
+      throws ScmItemNotFoundException, ScmCommunicationException, ScmBadRequestException {
+    GitlabUser user =
+        new GitlabApiClient(personalAccessToken.getScmProviderUrl())
+            .getUser(personalAccessToken.getToken());
+    return new GitUserData(user.getName(), user.getEmail());
+  }
+
+  protected String getLocalAuthenticateUrl() {
     return apiEndpoint
         + "/oauth/authenticate?oauth_provider="
         + OAUTH_PROVIDER_NAME
