@@ -71,14 +71,12 @@ public class GitlabUrlParserTest {
 
   /** Compare parsing */
   @Test(dataProvider = "parsing")
-  public void checkParsing(
-      String url, String project, String subGroups, String branch, String subfolder) {
+  public void checkParsing(String url, String project, String subGroups, String branch) {
     GitlabUrl gitlabUrl = gitlabUrlParser.parse(url);
 
     assertEquals(gitlabUrl.getProject(), project);
     assertEquals(gitlabUrl.getSubGroups(), subGroups);
     assertEquals(gitlabUrl.getBranch(), branch);
-    assertEquals(gitlabUrl.getSubfolder(), subfolder);
   }
 
   @Test
@@ -123,33 +121,29 @@ public class GitlabUrlParserTest {
   @DataProvider(name = "parsing")
   public Object[][] expectedParsing() {
     return new Object[][] {
-      {"https://gitlab1.com/user/project1.git", "project1", "user/project1", null, null},
-      {"https://gitlab1.com/user/project/test1.git", "test1", "user/project/test1", null, null},
+      {"https://gitlab1.com/user/project1.git", "project1", "user/project1", null},
+      {"https://gitlab1.com/user/project/test1.git", "test1", "user/project/test1", null},
       {
         "https://gitlab1.com/user/project/group1/group2/test1.git",
         "test1",
         "user/project/group1/group2/test1",
-        null,
         null
       },
-      {"https://gitlab1.com/user/project/", "project", "user/project", null, null},
-      {"https://gitlab1.com/user/project/repo/", "repo", "user/project/repo", null, null},
+      {"https://gitlab1.com/user/project/", "project", "user/project", null},
+      {"https://gitlab1.com/user/project/repo/", "repo", "user/project/repo", null},
+      {"https://gitlab1.com/user/project/-/tree/master/", "project", "user/project", "master"},
+      {"https://gitlab1.com/user/project/repo/-/tree/foo", "repo", "user/project/repo", "foo"},
       {
-        "https://gitlab1.com/user/project/-/tree/master/", "project", "user/project", "master", null
-      },
-      {
-        "https://gitlab1.com/user/project/repo/-/tree/foo/subfolder",
+        "https://gitlab1.com/user/project/repo/-/tree/branch/with/slash",
         "repo",
         "user/project/repo",
-        "foo",
-        "subfolder"
+        "branch/with/slash"
       },
       {
-        "https://gitlab1.com/user/project/group1/group2/repo/-/tree/foo/subfolder",
+        "https://gitlab1.com/user/project/group1/group2/repo/-/tree/foo/",
         "repo",
         "user/project/group1/group2/repo",
-        "foo",
-        "subfolder"
+        "foo"
       }
     };
   }
